@@ -9,7 +9,7 @@ require JSON::XS;
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(encode_json encode_json_unsafe decode_json decode_json_safe encode_utf8 decode_utf8);
-our $VERSION = 0.013005;
+our $VERSION = 0.014000;
 
 require XSLoader;
 XSLoader::load('JSON::XS::ByteString', $VERSION);
@@ -52,6 +52,15 @@ Because by the Perl nature, it's hard to determine if the outputted one is a str
 The nondeterministic will make the life harder if the acceptor is writing in other languages
 that strictly care about if it's string or number.
 
+=item *
+[EXPERIMENTAL] Transfer all the scalar-ref values into number of its referred values.
+
+Since the scalar reference is not valid in a JSON structure, we use this form as a stable numeric hint
+that will not be changed by how you use the value last time (the JSON::XS' nature).
+
+Note that C<decode_json> will not do the inverse. It will leave the number value be still a number value,
+not a reference to a number value.
+
 =item *
 Transfer all the utf8 encoded octet into multibyte-char strings before encoding to JSON string.
 If there're any malform octets, we'll transfer those bytes into questionmarks(?).
@@ -79,6 +88,10 @@ after C<JSON::XS::decode_json>.
 Because in the pure Perl world, there's insignificant difference between numeric or string.
 So I think we don't need to do it since the result will be used in Perl.
 
+=head2 I didn't transfer the numeric value from C<json_decode> back to reference values
+
+Let C<json_decode> preserve the identical structure as it received.
+
 =head1 FUNCTIONS
 
 =head2 $json_string = encode_json($perl_data)
@@ -116,6 +129,9 @@ sub encode_json {
 Same as C<encode_json> except the last step after C<JSON::XS::encode_json>.
 The argument will be upgraded to multibyte chars and never back.
 
+If there are any scalar reference as numeric hints,
+they will become numeric values.
+
 This function is a little faster than the C<encode_json>.
 Use it if you're sure that you'll not use the argument after the JSON call.
 
